==> mx-datetime_21.9.tar.xz: mx-datetime-21.9/translations/mx-datetime_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Datum &amp; Tid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; Tid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Verktyg för Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Få information från Hårdvaruklockan och visa den i rutan nedanför.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Avläs Hårdvaruklockan</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Använd korrektion för systematisk avdrift hos Hårdvaruklockan.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Justera Avdrift</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Tidsöverföring</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Ställ genast Systemklockan så den stämmer med den tid som nu registreras av Hårdvaruklockan.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Hårdvaruklocka till Systemklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Ställ genast Hårdvaruklockan så den stämmer med den tid som nu registreras av Systemklockan.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Systemklocka till Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Uppdatera avdriftsfaktorn för Hårdvaruklockan när den ställs.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Uppdatera avdriften</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Tidszon för Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Lokal tid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Universally Coordinated Time (eller Greenwich Meridian Time)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Nätverkstid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Flytta ner det valda objektet</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Flytta upp det valda objektet</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Ta bort det nuvarande objektet från listan</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Lägg till ett objekt till listan</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Uppdatera Systemklockan automatiskt  med NTP-servrar:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Uppdatera genast systemklockan med NTP-servrar.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Uppdatera Nu</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Lista över NTP-servrar att använda.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Adress</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Läser...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation>Justerar...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation>Systemklocka</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>%1 tiden överfördes till %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>%1 tiden kunde inte överföras till %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Uppdaterar...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>Systemklockan uppdaterades framgångsrikt.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>Systemklockan kunde inte uppdateras.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Nu är ingen av NTP-servrarna på listan aktiverad.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>Om MX Datum &amp; Tid</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Grafiskt program för att ställa in tid och datum i MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="600"/>
        <location filename="../datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation>MX Datum &amp; Tid Hjälp</translation>
    </message>
</context>
</TS>

==> mx-datetime_23.4.01.tar.xz: mx-datetime-23.4.01/translations/mx-datetime_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="604"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Datum &amp; Tid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; Tid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="298"/>
        <location filename="../datetime.cpp" line="305"/>
        <source>Hardware Clock</source>
        <translation>Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Verktyg för Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Få information från Hårdvaruklockan och visa den i rutan nedanför.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Avläs Hårdvaruklockan</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Använd korrektion för systematisk avdrift hos Hårdvaruklockan.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Justera Avdrift</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Tidsöverföring</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Ställ genast Systemklockan så den stämmer med den tid som nu registreras av Hårdvaruklockan.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Hårdvaruklocka till Systemklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Ställ genast Hårdvaruklockan så den stämmer med den tid som nu registreras av Systemklockan.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Systemklocka till Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Uppdatera avdriftsfaktorn för Hårdvaruklockan när den ställs.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Uppdatera avdriften</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Tidszon för Hårdvaruklocka</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Lokal tid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Universally Coordinated Time (eller Greenwich Meridian Time)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Nätverkstid</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Flytta ner det valda objektet</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Flytta upp det valda objektet</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Ta bort det nuvarande objektet från listan</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Lägg till ett objekt till listan</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Uppdatera Systemklockan automatiskt  med NTP-servrar:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Uppdatera genast systemklockan med NTP-servrar.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Uppdatera Nu</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Lista över NTP-servrar att använda.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Adress</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="272"/>
        <source>Reading...</source>
        <translation>Läser...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="286"/>
        <source>Adjusting...</source>
        <translation>Justerar...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="298"/>
        <location filename="../datetime.cpp" line="305"/>
        <source>System Clock</source>
        <translation>Systemklocka</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="311"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>%1 tiden överfördes till %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="314"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>%1 tiden kunde inte överföras till %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="354"/>
        <source>Updating...</source>
        <translation>Uppdaterar...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="367"/>
        <source>The system clock was updated successfully.</source>
        <translation>Systemklockan uppdaterades framgångsrikt.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="369"/>
        <source>The system clock could not be updated.</source>
        <translation>Systemklockan kunde inte uppdateras.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="371"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Nu är ingen av NTP-servrarna på listan aktiverad.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="604"/>
        <source>About MX Date &amp; Time</source>
        <translation>Om MX Datum &amp; Tid</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="605"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="606"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Grafiskt program för att ställa in tid och datum i MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="608"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="610"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licens</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Ändringslogg</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Avbryt</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Close</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="616"/>
        <source>MX Date &amp; Time Help</source>
        <translation>MX Datum &amp; Tid Hjälp</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation type="unfinished">Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Close</translation>
    </message>
</context>
</TS>
